Author: stas
Date: Thu Dec 30 14:40:22 2004
New Revision: 123737

URL: http://svn.apache.org/viewcvs?view=rev&rev=123737
Log:
cvs2svn

Modified:
   perl/modperl/trunk/util/getdiff.pl

Modified: perl/modperl/trunk/util/getdiff.pl
Url: 
http://svn.apache.org/viewcvs/perl/modperl/trunk/util/getdiff.pl?view=diff&rev=123737&p1=perl/modperl/trunk/util/getdiff.pl&r1=123736&p2=perl/modperl/trunk/util/getdiff.pl&r2=123737
==============================================================================
--- perl/modperl/trunk/util/getdiff.pl  (original)
+++ perl/modperl/trunk/util/getdiff.pl  Thu Dec 30 14:40:22 2004
@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
 # this script creates a diff against CVS
 # and against /dev/null for all files in ARGV
 # and prints it to STDOUT
 #
@@ -12,10 +12,7 @@
 # patch -p0 < newtest.patch
 
 # cvs diff
-my $o = `cvs diff -u`;
-
-# strip '? filename' cvs lines for unknown files
-$o =~ s/^\?.*\n//gm;
+my $o = `svn diff`;
 
 for (@ARGV) {
     $o .= "\n";
@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# this script creates a diff against CVS
+# this script creates a diff against SVN
 # and against /dev/null for all files in ARGV
 # and prints it to STDOUT

Reply via email to